# python-transformation
Provides a `Transformation` class that represents a transformation in 3D space. 
Currently, this class supports multiplication by other transformations, inversion and point projection.

## Installation
Install via
```bash
pip install transformation3d
```